==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkIncrementalPointLocator.java <==
// java wrapper for vtkIncrementalPointLocator object
//

package vtk;
import vtk.*;

public class vtkIncrementalPointLocator extends vtkAbstractPointLocator
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int FindClosestInsertedPoint_2(double id0[]);
  public int FindClosestInsertedPoint(double id0[])
    { return FindClosestInsertedPoint_2(id0); }

  private native int InitPointInsertion_3(vtkPoints id0,double id1[]);
  public int InitPointInsertion(vtkPoints id0,double id1[])
    { return InitPointInsertion_3(id0,id1); }

  private native int InitPointInsertion_4(vtkPoints id0,double id1[],int id2);
  public int InitPointInsertion(vtkPoints id0,double id1[],int id2)
    { return InitPointInsertion_4(id0,id1,id2); }

  private native int IsInsertedPoint_5(double id0,double id1,double id2);
  public int IsInsertedPoint(double id0,double id1,double id2)
    { return IsInsertedPoint_5(id0,id1,id2); }

  private native int IsInsertedPoint_6(double id0[]);
  public int IsInsertedPoint(double id0[])
    { return IsInsertedPoint_6(id0); }

  private native void InsertPoint_7(int id0,double id1[]);
  public void InsertPoint(int id0,double id1[])
    { InsertPoint_7(id0,id1); }

  private native int InsertNextPoint_8(double id0[]);
  public int InsertNextPoint(double id0[])
    { return InsertNextPoint_8(id0); }

  public vtkIncrementalPointLocator() { super(); }

  public vtkIncrementalPointLocator(long id) { super(id); }

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkIncrementalPointLocator.java <==
// java wrapper for vtkIncrementalPointLocator object
//

package vtk;
import vtk.*;

public class vtkIncrementalPointLocator extends vtkAbstractPointLocator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int FindClosestInsertedPoint_2(double id0[]);
  public int FindClosestInsertedPoint(double id0[])
    { return FindClosestInsertedPoint_2(id0); }

  private native int InitPointInsertion_3(vtkPoints id0,double id1[]);
  public int InitPointInsertion(vtkPoints id0,double id1[])
    { return InitPointInsertion_3(id0,id1); }

  private native int InitPointInsertion_4(vtkPoints id0,double id1[],int id2);
  public int InitPointInsertion(vtkPoints id0,double id1[],int id2)
    { return InitPointInsertion_4(id0,id1,id2); }

  private native int IsInsertedPoint_5(double id0,double id1,double id2);
  public int IsInsertedPoint(double id0,double id1,double id2)
    { return IsInsertedPoint_5(id0,id1,id2); }

  private native int IsInsertedPoint_6(double id0[]);
  public int IsInsertedPoint(double id0[])
    { return IsInsertedPoint_6(id0); }

  private native void InsertPoint_7(int id0,double id1[]);
  public void InsertPoint(int id0,double id1[])
    { InsertPoint_7(id0,id1); }

  private native int InsertNextPoint_8(double id0[]);
  public int InsertNextPoint(double id0[])
    { return InsertNextPoint_8(id0); }

  public vtkIncrementalPointLocator() { super(); }

  public vtkIncrementalPointLocator(long id) { super(id); }

}
